<?php
/**
 * Initialize the custom Theme Options.
 */
add_action( 'admin_init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 *
 * @return    void
 * @since     2.0
 */
function custom_theme_options() {
  
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'content'       => array( 
        array(
          'id'        => 'option_types_help',
          'title'     => __( 'Yardım', 'theme-text-domain' ),
          'content'   => '<p>' . __( 'Kullanım Kılavuzu tema klasörünün içerisindedir..', 'uck' ) . '</p>'
        )
      ),
      'sidebar'       => '<p>' . __( '<a href="http://www.uckan.net">http://www.uckan.net</a>', 'uck' ) . '</p>'
    ),
	
/*  Admin panel
/* ------------------------------------ */	
	'sections'        => array(
		array(
			'id'		=> 'general',
			'title'		=> 'Genel Ayarlar'
		),
		array(
			'id'		=> 'slider',
			'title'		=> 'Slider Ayarları'
		),
		array(
			'id'		=> 'blog',
			'title'		=> 'Blog'
		),
		array(
			'id'		=> 'footer',
			'title'		=> 'Footer'
		),
		array(
			'id'		=> 'sosyal',
			'title'		=> 'Sosyal Medya'
		),
		array(
			'id'		=> 'styling',
			'title'		=> 'Stiller'
		),
		array(
			'id'		=> 'reklam',
			'title'		=> 'Reklam Yönetimi'
		),
		array(
			'id'		=> 'daha_css',
			'title'		=> 'Daha Fazla CSS'
		),
	),
	
/*  Tema Ayarları
/* ------------------------------------ */
	'settings'        => array(
		
		// Genel Ayarlar: Responsive
		array(
			'id'		=> 'responsive',
			'label'		=> 'Responsive (Mobil)',
			'desc'		=> 'Mobil ve tablet cihazlarla entegre [ <strong>responsive.min.css</strong> ]',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'general'
		),
		// Blog: type
		array(
			'id'		=> 'posts_type',
			'label'		=> __('Anasayfa Yazı Görünümü', 'uck'),
			'std'		=> '2',
			'type'		=> 'select',
			'section'	=> 'general',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' => __('Standart Görünüm', 'uck')
				),
				array( 
					'value' => '2',
					'label' => __('Çift Kutu', 'uck')
				)
			)
		),

		// Featured Slider
		array(
			'id'		=> 'featured-slider',
			'label'		=> 'Anasayfa Slider',
			'desc'		=> 'Slider aktif/deaktif',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'slider'
		),
		array(
			'id'		=> 'featured-category',
			'label'		=> 'Slider Kategori',
			'desc'		=> 'Sliderda görünmesini istediğiniz yazıların bulunduğu kategoriyi seçin',
			'type'		=> 'category-select',
			'section'	=> 'slider'
		),
		array(
			'id'			=> 'featured-posts-count',
			'label'			=> 'Gösterilecek Yazı Sayısı',
			'desc'			=> 'Sliderda kaç tane yazı göstermek istiyorsunuz?',
			'std'			=> '5',
			'type'			=> 'numeric-slider',
			'section'		=> 'slider',
			'min_max_step'	=> '0,10,1'
		),
		//  Genel Ayarlar: Favicon
		array(
			'id'		=> 'favicon',
			'label'		=> 'Favicon',
			'desc'		=> '16x16 ebatlarında png/gif/ico formatında favicon ekleyebilirsiniz',
			'type'		=> 'upload',
			'section'	=> 'general'
		),
		// Genel Ayarlar: Logo
		array(
			'id'		=> 'text-logo',
			'label'		=> 'Yazıyla Logo',
			'desc'		=> 'Aşağıdan logo yüklemediyseniz logo alanında text olarak görünecek yazı',
			'type'		=> 'text',
			'std'       => 'Uckan Themes',
			'section'	=> 'general'
		),
		array(
			'id'		=> 'custom-logo',
			'label'		=> 'Logo',
			'desc'		=> 'Yüksekliği 50pixeli geçmemeli',
			'type'		=> 'upload',
			'section'	=> 'general'
		),
		array(
			'id'		=> 'no-images',
			'label'		=> 'Resim Yok Görseli',
			'desc'		=> 'Resim bulunmayan yazılarda kullanılacak görseli yükleyin',
			'type'		=> 'upload',
			'std'         => '/wp-content/themes/uckan/images/thumbnails.png',
			'section'	=> 'general'
		), 			
		// Blog: Kelime Limiti
		array(
			'id'			=> 'excerpt-length',
			'label'			=> 'Kelime Limiti',
			'desc'			=> 'Max kelime sayısı Def: 22',
			'std'			=> '22',
			'type'			=> 'numeric-slider',
			'section'		=> 'blog',
			'min_max_step'	=> '0,100,1'
		),
		// Blog: Yazı - Yazar Kutusu
		array(
			'id'		=> 'author-box',
			'label'		=> 'Single &mdash; Yazar Kutusu',
			'desc'		=> 'Yazı içerisinde yazar kutusu gözüksün/gözükmesin',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Yazı - Breadcrumb
		array(
			'id'		=> 'breadcrumb',
			'label'		=> 'Single &mdash; Breadcrumb',
			'desc'		=> 'Shows post author description, if it exists',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Yazı - Benzer Yazılar
		array(
			'id'		=> 'related-posts',
			'label'		=> 'Single &mdash; Benzer Yazılar',
			'desc'		=> 'Yazı içerisinde benzer yazıları göster/gösterme',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Yazı - Sosyal Medya Paylas
		array(
			'id'		=> 'sosyal-paylas',
			'label'		=> 'Single &mdash; Sosyal Medya Paylaş',
			'desc'		=> 'Yazı içerisinde sosyal medya sitelerinde paylaş butonlarını göster/gösterme ',
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),			
		// Footer: Copyright
		array(
			'id'		=> 'copyright',
			'label'		=> 'Footer Copyright',
			'desc'		=> 'En alt kısımda gözmesini istediğiniz yazıyı girin. Def: Site İsmi © 2014. All Rights Reserved.',
			'type'		=> 'textarea',
			'section'	=> 'footer'
		),
		// Footer: Yapımcı
		array(
			'id'		=> 'uckthemes',
			'label'		=> 'Tema Yapımcısı',
			'desc'		=> 'Tema yapımcısına destek olmak isterseniz alt kısımda yapımcı ismini gösterebilirsiniz',
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'footer'
		),
		// Styling: Geçerlilik
		array(
			'id'		=> 'dynamic-styles',
			'label'		=> 'Geçerlilik',
			'desc'		=> 'Aşağıda ayarlanan stilleri uygulamak istiyormusun?',
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'styling'
		),
		// Styling: Site Genişliği
		array(
			'id'			=> 'container-width',
			'label'			=> 'Max. Genişlik',
			'desc'			=> 'İdeal 1200px',
			'std'			=> '1200',
			'type'			=> 'numeric-slider',
			'section'		=> 'styling',
			'min_max_step'	=> '960,1600,1'
		),
		// Ozel CSS
		array(
        'id'          => 'demo_css',
        'label'       => __( 'CSS', 'theme-text-domain' ),
        'desc'        => 'Temanın genel yapısına eklemek istediğiniz <code>css kodları</code> varsa buradan halledebilirsiniz',
        'std'         => '#custom {
  {{demo_background}}
}',
        'type'        => 'css',
        'section'     => 'daha_css',
        'rows'        => '20',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

		// Styling: Topbar Background
		array(
			'id'		=> 'uck-ana-renk',
			'label'		=> 'Ana Renk',
			'std'		=> '#e51c23',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		array(
			'id'		=> 'uck-ikinci-renk',
			'label'		=> 'İkinci Renk',
			'std'		=> '#5F3131',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),		
		// Styling: Footer Background
		array(
			'id'		=> 'footer-background',
			'label'		=> 'Footer Background',
			'std'		=> '#fff',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Body Background
		array(
			'id'		=> 'body-background',
			'label'		=> 'Body Background',
			'std'		=> '#f2f2f2',
			'type'		=> 'colorpicker',
			'section'	=> 'styling'
		),
		// Sosyal Medya
		array(
			'id'		=> 'social-links',
			'label'		=> 'Social Links',
			'desc'		=> 'Create and organize your social links',
			'type'		=> 'list-item',
			'section'	=> 'sosyal',
			'choices'	=> array(),
			'settings'	=> array(
				array(
					'id'		=> 'social-icon',
					'label'		=> 'Icon Name',
					'desc'		=> 'Font Awesome icon names [<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank"><strong>View all</strong>]</a>  ',
					'std'		=> 'fa-',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-link',
					'label'		=> 'Link',
					'desc'		=> 'Enter the full url for your icon button',
					'std'		=> 'http://',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-color',
					'label'		=> 'Icon Color',
					'desc'		=> 'Set a unique color for your icon (optional)',
					'std'		=> '',
					'type'		=> 'colorpicker',
					'section'	=> 'sosyal'
				),
				array(
					'id'		=> 'social-target',
					'label'		=> 'Link Options',
					'desc'		=> '',
					'std'		=> '',
					'type'		=> 'checkbox',
					'choices'	=> array(
						array( 
							'value' => '_blank',
							'label' => 'Open in new window'
						)
					)
				)
			)
		),
		// // Reklam Aç-Kapa
		array(
			'id'		=> 'reklam-ackapa',
			'label'		=> 'Header Reklam Alanını Aç-Kapa',
			'desc'		=> 'Reklam alanlarını aç/kapa ',
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'reklam'
		),		
		// Reklam / Header / Menu Altı
		array(
			'id'		=> 'reklam-header',
			'label'		=> 'Header - Üst Menu Altı Reklam Alanı 720x90',
			'desc'		=> 'Menü altına 720x90 boyutlarında olan reklam kodunu giriniz..',
			'type'		=> 'textarea-simple',
			'rows'        => '5',
			'std'       => '<a href="http://www.uckan.net/reklam"><img src="http://i.imgur.com/JScVsL5.png" width="720" height="90" /></a>',
			'section'	=> 'reklam',
		),
	)
);

/*  Settings are not the same? Update the DB
/* ------------------------------------ */
	if ( $saved_settings !== $custom_settings ) {
		update_option( 'option_tree_settings', $custom_settings ); 
	} 
}
